window.Gleam.initSearch([{"doc":"glame","title":"glame","content":"# glame 🎮\n\nA client implementation of the [Source RCON Protocol](https://developer.valvesoftware.com/wiki/Source_RCON_Protocol),\ninpsired by [gorcon](https://github.com/gorcon/rcon).\n\n## Adding to your project\n\n```sh\ngleam add glame\n```\n\n## Usage\n\n```gleam\nimport gleam/io\nimport gleam/option.{None}\nimport gleam/string\nimport glame\n\npub fn main() {\n  case glame.dial(&quot;127.0.0.1&quot;, 25_575, &quot;password&quot;, None, None) {\n    Ok(conn) -&gt; {\n      case glame.execute(conn, &quot;ShowPlayers&quot;) {\n        Ok(res) -&gt; io.println(res)\n\n        Error(e) -&gt; io.println(string.inspect(e))\n      }\n    }\n\n    Error(e) -&gt; io.println(string.inspect(e))\n  }\n}\n```\n","url":"index.html"},{"doc":"glame/errors","title":"Error","content":"pub type Error {\n  PacketSizeTooSmall(packet: BitArray, body_size: Int)\n  BodyTooLarge(size: Int)\n  BodyEmpty\n  BodyNotUTF8(body_bytes: BitArray)\n  InvalidPacketPadding(packet: BitArray)\n  InvalidPacketType(packet: BitArray, typ: Int)\n  InvalidPacketStructure(packet: BitArray)\n  SocketError(e: mug.Error)\n  WrongResponseId(wanted: Int, got: Int)\n  WrongResponseType(wanted: Int, got: Int)\n  AuthFailed\n}\n\nPacketSizeTooSmall(packet: BitArray, body_size: Int)\n The packet size was less than 10\n\nBodyTooLarge(size: Int)\n The body was larger than 4096 bytes\n\nBodyEmpty\n Body was empty when trying to execute command\n\nBodyNotUTF8(body_bytes: BitArray)\n Body was not able to be parsed as a UTF-8\n\nInvalidPacketPadding(packet: BitArray)\n The packet was not terminated by &lt;&lt;0x00, 0x00&gt;&gt;\n\nInvalidPacketType(packet: BitArray, typ: Int)\n The packet type was not 0, 2, or 3\n\nInvalidPacketStructure(packet: BitArray)\n The packet could not be parsed as an RCON packet.\n\nSocketError(e: mug.Error)\n An error occurred at the socket level.\n\nWrongResponseId(wanted: Int, got: Int)\n A response did not have the expected id\n\nWrongResponseType(wanted: Int, got: Int)\n A response did not have the expected type\n\nAuthFailed\n Server responded with an id of -1 indicating that auth failed.\n Likely an invalid password\n\nSynonyms:\nglame/errors.Error\nglame/errors Error","url":"glame/errors.html#Error"},{"doc":"glame/errors","title":"glame/errors","content":"","url":"glame/errors.html"},{"doc":"glame/packet","title":"Packet","content":"pub type Packet {\n  Packet(size: Int, id: Int, typ: Int, body: BitArray)\n}\n Represents an RCON packet\nPacket(size: Int, id: Int, typ: Int, body: BitArray)\n\n\nSynonyms:\nglame/packet.Packet\nglame/packet Packet","url":"glame/packet.html#Packet"},{"doc":"glame/packet","title":"PacketType","content":"pub type PacketType {\n  ServerDataAuth\n  ServerDataAuthResponse\n  ServerDataExecCommand\n  ServerDataResponseValue\n}\n\nServerDataAuth\n The first packet sent by the client, which is used to authenticate\n with the server.\n\nServerDataAuthResponse\n A notification of the connection&#39;s current auth status.\n\nServerDataExecCommand\n A packet sent by the client with a command to be executed by the server.\n\nServerDataResponseValue\n A packet sent by the server with the result of a command.\n\nSynonyms:\nglame/packet.PacketType\nglame/packet PacketType","url":"glame/packet.html#PacketType"},{"doc":"glame/packet","title":"packet_header_size_bytes","content":"pub const packet_header_size_bytes: Int = 8\n How many bytes the header (i.e., id and type) takes up\nSynonyms:\nglame/packet.packet_header_size_bytes\nglame/packet packet_header_size_bytes","url":"glame/packet.html#packet_header_size_bytes"},{"doc":"glame/packet","title":"packet_padding_size_bytes","content":"pub const packet_padding_size_bytes: Int = 2\n How many bytes the padding (i.e., &lt;&lt;0x00, 0x00&gt;&gt;) takes up\nSynonyms:\nglame/packet.packet_padding_size_bytes\nglame/packet packet_padding_size_bytes","url":"glame/packet.html#packet_padding_size_bytes"},{"doc":"glame/packet","title":"from_bytes","content":"pub fn from_bytes(bytes: BitArray) -&gt; Result(Packet, Error)\n Constructs a {Packet} from a {BitArray}\nSynonyms:\nglame/packet.from_bytes\nglame/packet from_bytes","url":"glame/packet.html#from_bytes"},{"doc":"glame/packet","title":"max_packet_size_bytes","content":"pub fn max_packet_size_bytes() -&gt; Int\n Returns the maximum packet size supported by the RCON protocol.\nSynonyms:\nglame/packet.max_packet_size_bytes\nglame/packet max_packet_size_bytes","url":"glame/packet.html#max_packet_size_bytes"},{"doc":"glame/packet","title":"min_packet_size_bytes","content":"pub fn min_packet_size_bytes() -&gt; Int\n Returns the size of a packet with an empty body\nSynonyms:\nglame/packet.min_packet_size_bytes\nglame/packet min_packet_size_bytes","url":"glame/packet.html#min_packet_size_bytes"},{"doc":"glame/packet","title":"new","content":"pub fn new(\n  packet_type: PacketType,\n  packet_id: Int,\n  body: String,\n) -&gt; Result(Packet, Error)\n Constructs a new {Packet}\nSynonyms:\nglame/packet.new\nglame/packet new","url":"glame/packet.html#new"},{"doc":"glame/packet","title":"packet_type_to_int","content":"pub fn packet_type_to_int(pt: PacketType) -&gt; Int\n Converts a {PacketType} to its integer representation.\nSynonyms:\nglame/packet.packet_type_to_int\nglame/packet packet_type_to_int","url":"glame/packet.html#packet_type_to_int"},{"doc":"glame/packet","title":"to_bytes","content":"pub fn to_bytes(packet: Packet) -&gt; BitArray\n Serializes a {Packet} to a {BitArray}\nSynonyms:\nglame/packet.to_bytes\nglame/packet to_bytes","url":"glame/packet.html#to_bytes"},{"doc":"glame/packet","title":"glame/packet","content":"","url":"glame/packet.html"},{"doc":"glame","title":"Connection","content":"pub type Connection {\n  Connection(sock: mug.Socket, timeout_ms: Int)\n}\n Thin wrapper over a TCP socket\nConnection(sock: mug.Socket, timeout_ms: Int)\n\n\nSynonyms:\nglame.Connection\nglame Connection","url":"glame.html#Connection"},{"doc":"glame","title":"dial","content":"pub fn dial(\n  host: String,\n  port: Int,\n  password: String,\n  connect_timeout_ms: Option(Int),\n  rw_timeout_ms: Option(Int),\n) -&gt; Result(Connection, Error)\n Connects to the TCP socket and auths with the RCON server\nSynonyms:\nglame.dial\nglame dial","url":"glame.html#dial"},{"doc":"glame","title":"execute","content":"pub fn execute(\n  conn: Connection,\n  cmd: String,\n) -&gt; Result(String, Error)\n Executes a command on the RCON server\nSynonyms:\nglame.execute\nglame execute","url":"glame.html#execute"},{"doc":"glame","title":"glame","content":"","url":"glame.html"}]);